# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/bigquery/datatransfer_v1/proto/datasource.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.bigquery.datatransfer_v1.proto import (
    datatransfer_pb2 as google_dot_cloud_dot_bigquery_dot_datatransfer__v1_dot_proto_dot_datatransfer__pb2,
)
from google.cloud.bigquery.datatransfer_v1.proto import (
    transfer_pb2 as google_dot_cloud_dot_bigquery_dot_datatransfer__v1_dot_proto_dot_transfer__pb2,
)
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/bigquery/datatransfer_v1/proto/datasource.proto",
    package="google.cloud.bigquery.datatransfer.v1",
    syntax="proto3",
    serialized_options=_b(
        "\n)com.google.cloud.bigquery.datatransfer.v1B\017DataSourceProtoP\001ZQgoogle.golang.org/genproto/googleapis/cloud/bigquery/datatransfer/v1;datatransfer\252\002%Google.Cloud.BigQuery.DataTransfer.V1\312\002%Google\\Cloud\\BigQuery\\DataTransfer\\V1"
    ),
    serialized_pb=_b(
        '\n<google/cloud/bigquery/datatransfer_v1/proto/datasource.proto\x12%google.cloud.bigquery.datatransfer.v1\x1a\x1cgoogle/api/annotations.proto\x1a>google/cloud/bigquery/datatransfer_v1/proto/datatransfer.proto\x1a:google/cloud/bigquery/datatransfer_v1/proto/transfer.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/api/client.proto"\x9e\x0e\n\x10ImportedDataInfo\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12\x1c\n\x14\x64\x65stination_table_id\x18\x02 \x01(\t\x12%\n\x1d\x64\x65stination_table_description\x18\n \x01(\t\x12[\n\ntable_defs\x18\x03 \x03(\x0b\x32G.google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition\x12\x1e\n\x16user_defined_functions\x18\x04 \x03(\t\x12R\n\x11write_disposition\x18\x06 \x01(\x0e\x32\x37.google.cloud.bigquery.datatransfer.v1.WriteDisposition\x1a\xad\x03\n\x0b\x46ieldSchema\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12V\n\x04type\x18\x02 \x01(\x0e\x32H.google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.FieldSchema.Type\x12\x13\n\x0bis_repeated\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12T\n\x06schema\x18\x05 \x01(\x0b\x32\x44.google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.RecordSchema"\xb1\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x0b\n\x07INTEGER\x10\x02\x12\t\n\x05\x46LOAT\x10\x03\x12\n\n\x06RECORD\x10\x04\x12\t\n\x05\x42YTES\x10\x05\x12\x0b\n\x07\x42OOLEAN\x10\x06\x12\r\n\tTIMESTAMP\x10\x07\x12\x08\n\x04\x44\x41TE\x10\x08\x12\x08\n\x04TIME\x10\t\x12\x0c\n\x08\x44\x41TETIME\x10\n\x12\x0b\n\x07NUMERIC\x10\x0b\x12\r\n\tGEOGRAPHY\x10\x0c\x1a\x63\n\x0cRecordSchema\x12S\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x43.google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.FieldSchema\x1a\x91\x06\n\x0fTableDefinition\x12\x10\n\x08table_id\x18\x01 \x01(\t\x12\x13\n\x0bsource_uris\x18\x02 \x03(\t\x12N\n\x06\x66ormat\x18\x03 \x01(\x0e\x32>.google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.Format\x12\x17\n\x0fmax_bad_records\x18\x04 \x01(\x05\x12R\n\x08\x65ncoding\x18\x05 \x01(\x0e\x32@.google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.Encoding\x12g\n\x0b\x63sv_options\x18\x06 \x01(\x0b\x32R.google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.CsvOptions\x12T\n\x06schema\x18\x07 \x01(\x0b\x32\x44.google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.RecordSchema\x12\x39\n\x15ignore_unknown_values\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x9f\x02\n\nCsvOptions\x12\x35\n\x0f\x66ield_delimiter\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x15\x61llow_quoted_newlines\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\nquote_char\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x11skip_leading_rows\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x11\x61llow_jagged_rows\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue"~\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\x08\n\x04JSON\x10\x02\x12\x08\n\x04\x41VRO\x10\x03\x12\x0c\n\x08RECORDIO\x10\x04\x12\x0c\n\x08\x43OLUMNIO\x10\x05\x12\r\n\tCAPACITOR\x10\x06\x12\x0b\n\x07PARQUET\x10\x07\x12\x07\n\x03ORC\x10\x08">\n\x08\x45ncoding\x12\x18\n\x14\x45NCODING_UNSPECIFIED\x10\x00\x12\x0e\n\nISO_8859_1\x10\x01\x12\x08\n\x04UTF8\x10\x02"\x95\x01\n\x18UpdateTransferRunRequest\x12H\n\x0ctransfer_run\x18\x01 \x01(\x0b\x32\x32.google.cloud.bigquery.datatransfer.v1.TransferRun\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"\x80\x01\n\x1dLogTransferRunMessagesRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12Q\n\x11transfer_messages\x18\x02 \x03(\x0b\x32\x36.google.cloud.bigquery.datatransfer.v1.TransferMessage"\xab\x01\n\x18StartBigQueryJobsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12N\n\rimported_data\x18\x02 \x03(\x0b\x32\x37.google.cloud.bigquery.datatransfer.v1.ImportedDataInfo\x12\x18\n\x10user_credentials\x18\x03 \x01(\x0c\x12\x17\n\x0fmax_parallelism\x18\x08 \x01(\x05" \n\x10\x46inishRunRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\x90\x01\n!CreateDataSourceDefinitionRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12[\n\x16\x64\x61ta_source_definition\x18\x02 \x01(\x0b\x32;.google.cloud.bigquery.datatransfer.v1.DataSourceDefinition"\xb1\x01\n!UpdateDataSourceDefinitionRequest\x12[\n\x16\x64\x61ta_source_definition\x18\x01 \x01(\x0b\x32;.google.cloud.bigquery.datatransfer.v1.DataSourceDefinition\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"1\n!DeleteDataSourceDefinitionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t".\n\x1eGetDataSourceDefinitionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"Y\n ListDataSourceDefinitionsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05"\x9a\x01\n!ListDataSourceDefinitionsResponse\x12\\\n\x17\x64\x61ta_source_definitions\x18\x01 \x03(\x0b\x32;.google.cloud.bigquery.datatransfer.v1.DataSourceDefinition\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"\xcb\x02\n\x14\x44\x61taSourceDefinition\x12\x0c\n\x04name\x18\x15 \x01(\t\x12\x46\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32\x31.google.cloud.bigquery.datatransfer.v1.DataSource\x12!\n\x19transfer_run_pubsub_topic\x18\r \x01(\t\x12\x32\n\x0frun_time_offset\x18\x10 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x15\n\rsupport_email\x18\x16 \x01(\t\x12\x17\n\x0fservice_account\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\x12$\n\x1ctransfer_config_pubsub_topic\x18\x0c \x01(\t\x12\x1e\n\x16supported_location_ids\x18\x17 \x03(\t*[\n\x10WriteDisposition\x12!\n\x1dWRITE_DISPOSITION_UNSPECIFIED\x10\x00\x12\x12\n\x0eWRITE_TRUNCATE\x10\x01\x12\x10\n\x0cWRITE_APPEND\x10\x02\x32\x9d\x10\n\x11\x44\x61taSourceService\x12\xe7\x01\n\x11UpdateTransferRun\x12?.google.cloud.bigquery.datatransfer.v1.UpdateTransferRunRequest\x1a\x32.google.cloud.bigquery.datatransfer.v1.TransferRun"]\x82\xd3\xe4\x93\x02W2G/v1/{transfer_run.name=projects/*/locations/*/transferConfigs/*/runs/*}:\x0ctransfer_run\x12\xc9\x01\n\x16LogTransferRunMessages\x12\x44.google.cloud.bigquery.datatransfer.v1.LogTransferRunMessagesRequest\x1a\x16.google.protobuf.Empty"Q\x82\xd3\xe4\x93\x02K"F/v1/{name=projects/*/locations/*/transferConfigs/*/runs/*}:logMessages:\x01*\x12\xc5\x01\n\x11StartBigQueryJobs\x12?.google.cloud.bigquery.datatransfer.v1.StartBigQueryJobsRequest\x1a\x16.google.protobuf.Empty"W\x82\xd3\xe4\x93\x02Q"L/v1/{name=projects/*/locations/*/transferConfigs/*/runs/*}:startBigQueryJobs:\x01*\x12\xad\x01\n\tFinishRun\x12\x37.google.cloud.bigquery.datatransfer.v1.FinishRunRequest\x1a\x16.google.protobuf.Empty"O\x82\xd3\xe4\x93\x02I"D/v1/{name=projects/*/locations/*/transferConfigs/*/runs/*}:finishRun:\x01*\x12\xfe\x01\n\x1a\x43reateDataSourceDefinition\x12H.google.cloud.bigquery.datatransfer.v1.CreateDataSourceDefinitionRequest\x1a;.google.cloud.bigquery.datatransfer.v1.DataSourceDefinition"Y\x82\xd3\xe4\x93\x02S"9/v1/{parent=projects/*/locations/*}/dataSourceDefinitions:\x16\x64\x61ta_source_definition\x12\x95\x02\n\x1aUpdateDataSourceDefinition\x12H.google.cloud.bigquery.datatransfer.v1.UpdateDataSourceDefinitionRequest\x1a;.google.cloud.bigquery.datatransfer.v1.DataSourceDefinition"p\x82\xd3\xe4\x93\x02j2P/v1/{data_source_definition.name=projects/*/locations/*/dataSourceDefinitions/*}:\x16\x64\x61ta_source_definition\x12\xc1\x01\n\x1a\x44\x65leteDataSourceDefinition\x12H.google.cloud.bigquery.datatransfer.v1.DeleteDataSourceDefinitionRequest\x1a\x16.google.protobuf.Empty"A\x82\xd3\xe4\x93\x02;*9/v1/{name=projects/*/locations/*/dataSourceDefinitions/*}\x12\xe0\x01\n\x17GetDataSourceDefinition\x12\x45.google.cloud.bigquery.datatransfer.v1.GetDataSourceDefinitionRequest\x1a;.google.cloud.bigquery.datatransfer.v1.DataSourceDefinition"A\x82\xd3\xe4\x93\x02;\x12\x39/v1/{name=projects/*/locations/*/dataSourceDefinitions/*}\x12\xf1\x01\n\x19ListDataSourceDefinitions\x12G.google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsRequest\x1aH.google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsResponse"A\x82\xd3\xe4\x93\x02;\x12\x39/v1/{parent=projects/*/locations/*}/dataSourceDefinitions\x1a&\xca\x41#bigquerydatatransfer.googleapis.comB\xe1\x01\n)com.google.cloud.bigquery.datatransfer.v1B\x0f\x44\x61taSourceProtoP\x01ZQgoogle.golang.org/genproto/googleapis/cloud/bigquery/datatransfer/v1;datatransfer\xaa\x02%Google.Cloud.BigQuery.DataTransfer.V1\xca\x02%Google\\Cloud\\BigQuery\\DataTransfer\\V1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_bigquery_dot_datatransfer__v1_dot_proto_dot_datatransfer__pb2.DESCRIPTOR,
        google_dot_cloud_dot_bigquery_dot_datatransfer__v1_dot_proto_dot_transfer__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
    ],
)

_WRITEDISPOSITION = _descriptor.EnumDescriptor(
    name="WriteDisposition",
    full_name="google.cloud.bigquery.datatransfer.v1.WriteDisposition",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="WRITE_DISPOSITION_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="WRITE_TRUNCATE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="WRITE_APPEND", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3766,
    serialized_end=3857,
)
_sym_db.RegisterEnumDescriptor(_WRITEDISPOSITION)

WriteDisposition = enum_type_wrapper.EnumTypeWrapper(_WRITEDISPOSITION)
WRITE_DISPOSITION_UNSPECIFIED = 0
WRITE_TRUNCATE = 1
WRITE_APPEND = 2


_IMPORTEDDATAINFO_FIELDSCHEMA_TYPE = _descriptor.EnumDescriptor(
    name="Type",
    full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.FieldSchema.Type",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="STRING", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="INTEGER", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="FLOAT", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="RECORD", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="BYTES", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="BOOLEAN", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TIMESTAMP", index=7, number=7, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DATE", index=8, number=8, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TIME", index=9, number=9, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DATETIME", index=10, number=10, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="NUMERIC", index=11, number=11, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="GEOGRAPHY", index=12, number=12, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1007,
    serialized_end=1184,
)
_sym_db.RegisterEnumDescriptor(_IMPORTEDDATAINFO_FIELDSCHEMA_TYPE)

_IMPORTEDDATAINFO_FORMAT = _descriptor.EnumDescriptor(
    name="Format",
    full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.Format",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="FORMAT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="CSV", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="JSON", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="AVRO", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="RECORDIO", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="COLUMNIO", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CAPACITOR", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PARQUET", index=7, number=7, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ORC", index=8, number=8, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2075,
    serialized_end=2201,
)
_sym_db.RegisterEnumDescriptor(_IMPORTEDDATAINFO_FORMAT)

_IMPORTEDDATAINFO_ENCODING = _descriptor.EnumDescriptor(
    name="Encoding",
    full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.Encoding",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ENCODING_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ISO_8859_1", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="UTF8", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2203,
    serialized_end=2265,
)
_sym_db.RegisterEnumDescriptor(_IMPORTEDDATAINFO_ENCODING)


_IMPORTEDDATAINFO_FIELDSCHEMA = _descriptor.Descriptor(
    name="FieldSchema",
    full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.FieldSchema",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="field_name",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.FieldSchema.field_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.FieldSchema.type",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="is_repeated",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.FieldSchema.is_repeated",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.FieldSchema.description",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="schema",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.FieldSchema.schema",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_IMPORTEDDATAINFO_FIELDSCHEMA_TYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=755,
    serialized_end=1184,
)

_IMPORTEDDATAINFO_RECORDSCHEMA = _descriptor.Descriptor(
    name="RecordSchema",
    full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.RecordSchema",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="fields",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.RecordSchema.fields",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1186,
    serialized_end=1285,
)

_IMPORTEDDATAINFO_TABLEDEFINITION_CSVOPTIONS = _descriptor.Descriptor(
    name="CsvOptions",
    full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.CsvOptions",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="field_delimiter",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.CsvOptions.field_delimiter",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="allow_quoted_newlines",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.CsvOptions.allow_quoted_newlines",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="quote_char",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.CsvOptions.quote_char",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="skip_leading_rows",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.CsvOptions.skip_leading_rows",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="allow_jagged_rows",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.CsvOptions.allow_jagged_rows",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1786,
    serialized_end=2073,
)

_IMPORTEDDATAINFO_TABLEDEFINITION = _descriptor.Descriptor(
    name="TableDefinition",
    full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="table_id",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.table_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="source_uris",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.source_uris",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="format",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.format",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="max_bad_records",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.max_bad_records",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="encoding",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.encoding",
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="csv_options",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.csv_options",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="schema",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.schema",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="ignore_unknown_values",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.ignore_unknown_values",
            index=7,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_IMPORTEDDATAINFO_TABLEDEFINITION_CSVOPTIONS],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1288,
    serialized_end=2073,
)

_IMPORTEDDATAINFO = _descriptor.Descriptor(
    name="ImportedDataInfo",
    full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="sql",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.sql",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="destination_table_id",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.destination_table_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="destination_table_description",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.destination_table_description",
            index=2,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="table_defs",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.table_defs",
            index=3,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="user_defined_functions",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.user_defined_functions",
            index=4,
            number=4,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="write_disposition",
            full_name="google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.write_disposition",
            index=5,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[
        _IMPORTEDDATAINFO_FIELDSCHEMA,
        _IMPORTEDDATAINFO_RECORDSCHEMA,
        _IMPORTEDDATAINFO_TABLEDEFINITION,
    ],
    enum_types=[_IMPORTEDDATAINFO_FORMAT, _IMPORTEDDATAINFO_ENCODING],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=443,
    serialized_end=2265,
)


_UPDATETRANSFERRUNREQUEST = _descriptor.Descriptor(
    name="UpdateTransferRunRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.UpdateTransferRunRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="transfer_run",
            full_name="google.cloud.bigquery.datatransfer.v1.UpdateTransferRunRequest.transfer_run",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.bigquery.datatransfer.v1.UpdateTransferRunRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2268,
    serialized_end=2417,
)


_LOGTRANSFERRUNMESSAGESREQUEST = _descriptor.Descriptor(
    name="LogTransferRunMessagesRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.LogTransferRunMessagesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.LogTransferRunMessagesRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="transfer_messages",
            full_name="google.cloud.bigquery.datatransfer.v1.LogTransferRunMessagesRequest.transfer_messages",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2420,
    serialized_end=2548,
)


_STARTBIGQUERYJOBSREQUEST = _descriptor.Descriptor(
    name="StartBigQueryJobsRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.StartBigQueryJobsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.StartBigQueryJobsRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="imported_data",
            full_name="google.cloud.bigquery.datatransfer.v1.StartBigQueryJobsRequest.imported_data",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="user_credentials",
            full_name="google.cloud.bigquery.datatransfer.v1.StartBigQueryJobsRequest.user_credentials",
            index=2,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b(""),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="max_parallelism",
            full_name="google.cloud.bigquery.datatransfer.v1.StartBigQueryJobsRequest.max_parallelism",
            index=3,
            number=8,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2551,
    serialized_end=2722,
)


_FINISHRUNREQUEST = _descriptor.Descriptor(
    name="FinishRunRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.FinishRunRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.FinishRunRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2724,
    serialized_end=2756,
)


_CREATEDATASOURCEDEFINITIONREQUEST = _descriptor.Descriptor(
    name="CreateDataSourceDefinitionRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.CreateDataSourceDefinitionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.bigquery.datatransfer.v1.CreateDataSourceDefinitionRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="data_source_definition",
            full_name="google.cloud.bigquery.datatransfer.v1.CreateDataSourceDefinitionRequest.data_source_definition",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2759,
    serialized_end=2903,
)


_UPDATEDATASOURCEDEFINITIONREQUEST = _descriptor.Descriptor(
    name="UpdateDataSourceDefinitionRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.UpdateDataSourceDefinitionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="data_source_definition",
            full_name="google.cloud.bigquery.datatransfer.v1.UpdateDataSourceDefinitionRequest.data_source_definition",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.bigquery.datatransfer.v1.UpdateDataSourceDefinitionRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2906,
    serialized_end=3083,
)


_DELETEDATASOURCEDEFINITIONREQUEST = _descriptor.Descriptor(
    name="DeleteDataSourceDefinitionRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.DeleteDataSourceDefinitionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.DeleteDataSourceDefinitionRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3085,
    serialized_end=3134,
)


_GETDATASOURCEDEFINITIONREQUEST = _descriptor.Descriptor(
    name="GetDataSourceDefinitionRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.GetDataSourceDefinitionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.GetDataSourceDefinitionRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3136,
    serialized_end=3182,
)


_LISTDATASOURCEDEFINITIONSREQUEST = _descriptor.Descriptor(
    name="ListDataSourceDefinitionsRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsRequest.page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsRequest.page_size",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3184,
    serialized_end=3273,
)


_LISTDATASOURCEDEFINITIONSRESPONSE = _descriptor.Descriptor(
    name="ListDataSourceDefinitionsResponse",
    full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="data_source_definitions",
            full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsResponse.data_source_definitions",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3276,
    serialized_end=3430,
)


_DATASOURCEDEFINITION = _descriptor.Descriptor(
    name="DataSourceDefinition",
    full_name="google.cloud.bigquery.datatransfer.v1.DataSourceDefinition",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceDefinition.name",
            index=0,
            number=21,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="data_source",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceDefinition.data_source",
            index=1,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="transfer_run_pubsub_topic",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceDefinition.transfer_run_pubsub_topic",
            index=2,
            number=13,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="run_time_offset",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceDefinition.run_time_offset",
            index=3,
            number=16,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="support_email",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceDefinition.support_email",
            index=4,
            number=22,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="service_account",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceDefinition.service_account",
            index=5,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="disabled",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceDefinition.disabled",
            index=6,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="transfer_config_pubsub_topic",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceDefinition.transfer_config_pubsub_topic",
            index=7,
            number=12,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="supported_location_ids",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceDefinition.supported_location_ids",
            index=8,
            number=23,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3433,
    serialized_end=3764,
)

_IMPORTEDDATAINFO_FIELDSCHEMA.fields_by_name[
    "type"
].enum_type = _IMPORTEDDATAINFO_FIELDSCHEMA_TYPE
_IMPORTEDDATAINFO_FIELDSCHEMA.fields_by_name[
    "schema"
].message_type = _IMPORTEDDATAINFO_RECORDSCHEMA
_IMPORTEDDATAINFO_FIELDSCHEMA.containing_type = _IMPORTEDDATAINFO
_IMPORTEDDATAINFO_FIELDSCHEMA_TYPE.containing_type = _IMPORTEDDATAINFO_FIELDSCHEMA
_IMPORTEDDATAINFO_RECORDSCHEMA.fields_by_name[
    "fields"
].message_type = _IMPORTEDDATAINFO_FIELDSCHEMA
_IMPORTEDDATAINFO_RECORDSCHEMA.containing_type = _IMPORTEDDATAINFO
_IMPORTEDDATAINFO_TABLEDEFINITION_CSVOPTIONS.fields_by_name[
    "field_delimiter"
].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMPORTEDDATAINFO_TABLEDEFINITION_CSVOPTIONS.fields_by_name[
    "allow_quoted_newlines"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_IMPORTEDDATAINFO_TABLEDEFINITION_CSVOPTIONS.fields_by_name[
    "quote_char"
].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMPORTEDDATAINFO_TABLEDEFINITION_CSVOPTIONS.fields_by_name[
    "skip_leading_rows"
].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMPORTEDDATAINFO_TABLEDEFINITION_CSVOPTIONS.fields_by_name[
    "allow_jagged_rows"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_IMPORTEDDATAINFO_TABLEDEFINITION_CSVOPTIONS.containing_type = (
    _IMPORTEDDATAINFO_TABLEDEFINITION
)
_IMPORTEDDATAINFO_TABLEDEFINITION.fields_by_name[
    "format"
].enum_type = _IMPORTEDDATAINFO_FORMAT
_IMPORTEDDATAINFO_TABLEDEFINITION.fields_by_name[
    "encoding"
].enum_type = _IMPORTEDDATAINFO_ENCODING
_IMPORTEDDATAINFO_TABLEDEFINITION.fields_by_name[
    "csv_options"
].message_type = _IMPORTEDDATAINFO_TABLEDEFINITION_CSVOPTIONS
_IMPORTEDDATAINFO_TABLEDEFINITION.fields_by_name[
    "schema"
].message_type = _IMPORTEDDATAINFO_RECORDSCHEMA
_IMPORTEDDATAINFO_TABLEDEFINITION.fields_by_name[
    "ignore_unknown_values"
].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_IMPORTEDDATAINFO_TABLEDEFINITION.containing_type = _IMPORTEDDATAINFO
_IMPORTEDDATAINFO.fields_by_name[
    "table_defs"
].message_type = _IMPORTEDDATAINFO_TABLEDEFINITION
_IMPORTEDDATAINFO.fields_by_name["write_disposition"].enum_type = _WRITEDISPOSITION
_IMPORTEDDATAINFO_FORMAT.containing_type = _IMPORTEDDATAINFO
_IMPORTEDDATAINFO_ENCODING.containing_type = _IMPORTEDDATAINFO
_UPDATETRANSFERRUNREQUEST.fields_by_name[
    "transfer_run"
].message_type = (
    google_dot_cloud_dot_bigquery_dot_datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERRUN
)
_UPDATETRANSFERRUNREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LOGTRANSFERRUNMESSAGESREQUEST.fields_by_name[
    "transfer_messages"
].message_type = (
    google_dot_cloud_dot_bigquery_dot_datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERMESSAGE
)
_STARTBIGQUERYJOBSREQUEST.fields_by_name[
    "imported_data"
].message_type = _IMPORTEDDATAINFO
_CREATEDATASOURCEDEFINITIONREQUEST.fields_by_name[
    "data_source_definition"
].message_type = _DATASOURCEDEFINITION
_UPDATEDATASOURCEDEFINITIONREQUEST.fields_by_name[
    "data_source_definition"
].message_type = _DATASOURCEDEFINITION
_UPDATEDATASOURCEDEFINITIONREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTDATASOURCEDEFINITIONSRESPONSE.fields_by_name[
    "data_source_definitions"
].message_type = _DATASOURCEDEFINITION
_DATASOURCEDEFINITION.fields_by_name[
    "data_source"
].message_type = (
    google_dot_cloud_dot_bigquery_dot_datatransfer__v1_dot_proto_dot_datatransfer__pb2._DATASOURCE
)
_DATASOURCEDEFINITION.fields_by_name[
    "run_time_offset"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name["ImportedDataInfo"] = _IMPORTEDDATAINFO
DESCRIPTOR.message_types_by_name["UpdateTransferRunRequest"] = _UPDATETRANSFERRUNREQUEST
DESCRIPTOR.message_types_by_name[
    "LogTransferRunMessagesRequest"
] = _LOGTRANSFERRUNMESSAGESREQUEST
DESCRIPTOR.message_types_by_name["StartBigQueryJobsRequest"] = _STARTBIGQUERYJOBSREQUEST
DESCRIPTOR.message_types_by_name["FinishRunRequest"] = _FINISHRUNREQUEST
DESCRIPTOR.message_types_by_name[
    "CreateDataSourceDefinitionRequest"
] = _CREATEDATASOURCEDEFINITIONREQUEST
DESCRIPTOR.message_types_by_name[
    "UpdateDataSourceDefinitionRequest"
] = _UPDATEDATASOURCEDEFINITIONREQUEST
DESCRIPTOR.message_types_by_name[
    "DeleteDataSourceDefinitionRequest"
] = _DELETEDATASOURCEDEFINITIONREQUEST
DESCRIPTOR.message_types_by_name[
    "GetDataSourceDefinitionRequest"
] = _GETDATASOURCEDEFINITIONREQUEST
DESCRIPTOR.message_types_by_name[
    "ListDataSourceDefinitionsRequest"
] = _LISTDATASOURCEDEFINITIONSREQUEST
DESCRIPTOR.message_types_by_name[
    "ListDataSourceDefinitionsResponse"
] = _LISTDATASOURCEDEFINITIONSRESPONSE
DESCRIPTOR.message_types_by_name["DataSourceDefinition"] = _DATASOURCEDEFINITION
DESCRIPTOR.enum_types_by_name["WriteDisposition"] = _WRITEDISPOSITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ImportedDataInfo = _reflection.GeneratedProtocolMessageType(
    "ImportedDataInfo",
    (_message.Message,),
    dict(
        FieldSchema=_reflection.GeneratedProtocolMessageType(
            "FieldSchema",
            (_message.Message,),
            dict(
                DESCRIPTOR=_IMPORTEDDATAINFO_FIELDSCHEMA,
                __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
                __doc__="""Defines schema of a field in the imported data.
    
    
    Attributes:
        field_name:
            Field name. Matches: [A-Za-z\_][A-Za-z\_0-9]{0,127}
        type:
            Field type
        is_repeated:
            Is field repeated.
        description:
            Description for this field.
        schema:
            Present iff type == RECORD.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.FieldSchema)
            ),
        ),
        RecordSchema=_reflection.GeneratedProtocolMessageType(
            "RecordSchema",
            (_message.Message,),
            dict(
                DESCRIPTOR=_IMPORTEDDATAINFO_RECORDSCHEMA,
                __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
                __doc__="""Describes schema of the data to be ingested.
    
    
    Attributes:
        fields:
            One field per column in the record.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.RecordSchema)
            ),
        ),
        TableDefinition=_reflection.GeneratedProtocolMessageType(
            "TableDefinition",
            (_message.Message,),
            dict(
                CsvOptions=_reflection.GeneratedProtocolMessageType(
                    "CsvOptions",
                    (_message.Message,),
                    dict(
                        DESCRIPTOR=_IMPORTEDDATAINFO_TABLEDEFINITION_CSVOPTIONS,
                        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
                        __doc__="""CSV specific options.
      
      
      Attributes:
          field_delimiter:
              The delimiter. We currently restrict this to U+0001 to U+00FF
              and apply additional constraints during validation.
          allow_quoted_newlines:
              Whether CSV files are allowed to have quoted newlines. If
              quoted newlines are allowed, we can't split CSV files.
          quote_char:
              The quote character. We currently restrict this to U+0000 to
              U+00FF and apply additional constraints during validation. Set
              to ':raw-latex:`\0`' to indicate no quote is used.
          skip_leading_rows:
              Number of leading rows to skip.
          allow_jagged_rows:
              Accept rows that are missing trailing optional columns.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition.CsvOptions)
                    ),
                ),
                DESCRIPTOR=_IMPORTEDDATAINFO_TABLEDEFINITION,
                __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
                __doc__="""External table definition. These tables can be referenced with 'name' in
    the query and can be read just like any other table.
    
    
    Attributes:
        table_id:
            BigQuery table\_id (required). This will be used to reference
            this table in the query.
        source_uris:
            URIs for the data to be imported. All URIs must be from the
            same storage system.
        format:
            Describes the format of the data in source\_uri.
        max_bad_records:
            Specify the maximum number of bad records that can be ignored.
            If bad records exceed this threshold the query is aborted.
        encoding:
            Character encoding of the input when applicable (CSV, JSON).
            Defaults to UTF8.
        csv_options:
            CSV specific options.
        schema:
            Optional schema for the data. When not specified for JSON and
            CSV formats we will try to detect it automatically.
        ignore_unknown_values:
            Indicates if extra values that are not represented in the
            table schema is allowed.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ImportedDataInfo.TableDefinition)
            ),
        ),
        DESCRIPTOR=_IMPORTEDDATAINFO,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""Describes data which should be imported.
  
  
  Attributes:
      sql:
          SQL query to run. When empty, API checks that there is only
          one table\_def specified and loads this table. Only Standard
          SQL queries are accepted. Legacy SQL is not allowed.
      destination_table_id:
          Table where results should be written.
      destination_table_description:
          The description of a destination table. This can be several
          sentences or paragraphs describing the table contents in
          detail.
      table_defs:
          When used WITHOUT the "sql" parameter, describes the schema of
          the destination table. When used WITH the "sql" parameter,
          describes tables with data stored outside of BigQuery.
      user_defined_functions:
          Inline code for User-defined function resources. Ignored when
          "sql" parameter is empty.
      write_disposition:
          Specifies the action if the destination table already exists.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ImportedDataInfo)
    ),
)
_sym_db.RegisterMessage(ImportedDataInfo)
_sym_db.RegisterMessage(ImportedDataInfo.FieldSchema)
_sym_db.RegisterMessage(ImportedDataInfo.RecordSchema)
_sym_db.RegisterMessage(ImportedDataInfo.TableDefinition)
_sym_db.RegisterMessage(ImportedDataInfo.TableDefinition.CsvOptions)

UpdateTransferRunRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTransferRunRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATETRANSFERRUNREQUEST,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""A request to update a transfer run.
  
  
  Attributes:
      transfer_run:
          Run name must be set and correspond to an already existing
          run. Only state, error\_status, and data\_version fields will
          be updated. All other fields will be ignored.
      update_mask:
          Required list of fields to be updated in this request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.UpdateTransferRunRequest)
    ),
)
_sym_db.RegisterMessage(UpdateTransferRunRequest)

LogTransferRunMessagesRequest = _reflection.GeneratedProtocolMessageType(
    "LogTransferRunMessagesRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LOGTRANSFERRUNMESSAGESREQUEST,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""A request to add transfer status messages to the run.
  
  
  Attributes:
      name:
          Name of the resource in the form: "projects/{project\_id}/loca
          tions/{location\_id}/transferConfigs/{config\_id}/runs/{run\_i
          d}"
      transfer_messages:
          Messages to append.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.LogTransferRunMessagesRequest)
    ),
)
_sym_db.RegisterMessage(LogTransferRunMessagesRequest)

StartBigQueryJobsRequest = _reflection.GeneratedProtocolMessageType(
    "StartBigQueryJobsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_STARTBIGQUERYJOBSREQUEST,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""A request to start and monitor a BigQuery load job.
  
  
  Attributes:
      name:
          Name of the resource in the form: "projects/{project\_id}/loca
          tions/{location\_id}/transferConfigs/{config\_id}/runs/{run\_i
          d}"
      imported_data:
          Import jobs which should be started and monitored.
      user_credentials:
          User credentials which should be used to start/monitor
          BigQuery jobs. If not specified, then jobs are started using
          data source service account credentials. This may be OAuth
          token or JWT token.
      max_parallelism:
          The number of BQ Jobs that can run in parallel.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.StartBigQueryJobsRequest)
    ),
)
_sym_db.RegisterMessage(StartBigQueryJobsRequest)

FinishRunRequest = _reflection.GeneratedProtocolMessageType(
    "FinishRunRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_FINISHRUNREQUEST,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""A request to finish a run.
  
  
  Attributes:
      name:
          Name of the resource in the form: "projects/{project\_id}/loca
          tions/{location\_id}/transferConfigs/{config\_id}/runs/{run\_i
          d}"
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.FinishRunRequest)
    ),
)
_sym_db.RegisterMessage(FinishRunRequest)

CreateDataSourceDefinitionRequest = _reflection.GeneratedProtocolMessageType(
    "CreateDataSourceDefinitionRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATEDATASOURCEDEFINITIONREQUEST,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""Represents the request of the CreateDataSourceDefinition method.
  
  
  Attributes:
      parent:
          The BigQuery project id for which data source definition is
          associated. Must be in the form:
          ``projects/{project_id}/locations/{location_id}``
      data_source_definition:
          Data source definition.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.CreateDataSourceDefinitionRequest)
    ),
)
_sym_db.RegisterMessage(CreateDataSourceDefinitionRequest)

UpdateDataSourceDefinitionRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateDataSourceDefinitionRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATEDATASOURCEDEFINITIONREQUEST,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""Represents the request of the UpdateDataSourceDefinition method.
  
  
  Attributes:
      data_source_definition:
          Data source definition.
      update_mask:
          Update field mask.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.UpdateDataSourceDefinitionRequest)
    ),
)
_sym_db.RegisterMessage(UpdateDataSourceDefinitionRequest)

DeleteDataSourceDefinitionRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteDataSourceDefinitionRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEDATASOURCEDEFINITIONREQUEST,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""Represents the request of the DeleteDataSourceDefinition method. All
  transfer configs associated with the data source must be deleted first,
  before the data source can be deleted.
  
  
  Attributes:
      name:
          The field will contain name of the resource requested, for
          example: ``projects/{project_id}/locations/{location_id}/dataS
          ourceDefinitions/{data_source_id}``
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.DeleteDataSourceDefinitionRequest)
    ),
)
_sym_db.RegisterMessage(DeleteDataSourceDefinitionRequest)

GetDataSourceDefinitionRequest = _reflection.GeneratedProtocolMessageType(
    "GetDataSourceDefinitionRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETDATASOURCEDEFINITIONREQUEST,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""Represents the request of the GetDataSourceDefinition method.
  
  
  Attributes:
      name:
          The field will contain name of the resource requested.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.GetDataSourceDefinitionRequest)
    ),
)
_sym_db.RegisterMessage(GetDataSourceDefinitionRequest)

ListDataSourceDefinitionsRequest = _reflection.GeneratedProtocolMessageType(
    "ListDataSourceDefinitionsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTDATASOURCEDEFINITIONSREQUEST,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""Represents the request of the ListDataSourceDefinitions method.
  
  
  Attributes:
      parent:
          The BigQuery project id for which data sources should be
          returned. Must be in the form:
          ``projects/{project_id}/locations/{location_id}``
      page_token:
          Pagination token, which can be used to request a specific page
          of ``ListDataSourceDefinitionsRequest`` list results. For
          multiple-page results, ``ListDataSourceDefinitionsResponse``
          outputs a ``next_page`` token, which can be used as the
          ``page_token`` value to request the next page of the list
          results.
      page_size:
          Page size. The default page size is the maximum value of 1000
          results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsRequest)
    ),
)
_sym_db.RegisterMessage(ListDataSourceDefinitionsRequest)

ListDataSourceDefinitionsResponse = _reflection.GeneratedProtocolMessageType(
    "ListDataSourceDefinitionsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTDATASOURCEDEFINITIONSRESPONSE,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""Returns a list of supported data source definitions.
  
  
  Attributes:
      data_source_definitions:
          List of supported data source definitions.
      next_page_token:
          Output only. The next-pagination token. For multiple-page list
          results, this token can be used as the
          ``ListDataSourceDefinitionsRequest.page_token`` to request the
          next page of the list results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ListDataSourceDefinitionsResponse)
    ),
)
_sym_db.RegisterMessage(ListDataSourceDefinitionsResponse)

DataSourceDefinition = _reflection.GeneratedProtocolMessageType(
    "DataSourceDefinition",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DATASOURCEDEFINITION,
        __module__="google.cloud.bigquery.datatransfer_v1.proto.datasource_pb2",
        __doc__="""Represents the data source definition.
  
  
  Attributes:
      name:
          The resource name of the data source definition. Data source
          definition names have the form ``projects/{project_id}/locatio
          ns/{location}/dataSourceDefinitions/{data_source_id}``.
      data_source:
          Data source metadata.
      transfer_run_pubsub_topic:
          The Pub/Sub topic to be used for broadcasting a message when a
          transfer run is created. Both this topic and
          transfer\_config\_pubsub\_topic can be set to a custom topic.
          By default, both topics are auto-generated if none of them is
          provided when creating the definition. However, if one topic
          is manually set, the other topic has to be manually set as
          well. The only difference is that transfer\_run\_pubsub\_topic
          must be a non-empty Pub/Sub topic, but
          transfer\_config\_pubsub\_topic can be set to empty. The
          comments about "{location}" for
          transfer\_config\_pubsub\_topic apply here too.
      run_time_offset:
          Duration which should be added to schedule\_time to calculate
          run\_time when job is scheduled. Only applicable for
          automatically scheduled transfer runs. Used to start a run
          early on a data source that supports continuous data refresh
          to compensate for unknown timezone offsets. Use a negative
          number to start a run late for data sources not supporting
          continuous data refresh.
      support_email:
          Support e-mail address of the OAuth client's Brand, which
          contains the consent screen data.
      service_account:
          When service account is specified, BigQuery will share created
          dataset with the given service account. Also, this service
          account will be eligible to perform status updates and message
          logging for data transfer runs for the corresponding
          data\_source\_id.
      disabled:
          Is data source disabled? If true, data\_source is not visible.
          API will also stop returning any data transfer configs and/or
          runs associated with the data source. This setting has higher
          priority than whitelisted\_project\_ids.
      transfer_config_pubsub_topic:
          The Pub/Sub topic to use for broadcasting a message for
          transfer config. If empty, a message will not be broadcasted.
          Both this topic and transfer\_run\_pubsub\_topic are auto-
          generated if none of them is provided when creating the
          definition. It is recommended to provide
          transfer\_config\_pubsub\_topic if a user-owned
          transfer\_run\_pubsub\_topic is provided. Otherwise, it will
          be set to empty. If "{location}" is found in the value, then
          that means, data source wants to handle message separately for
          datasets in different regions. We will replace {location} with
          the actual dataset location, as the actual topic name. For
          example, projects/connector/topics/scheduler-{location} could
          become projects/connector/topics/scheduler-us. If "{location}"
          is not found, then we will use the input value as topic name.
      supported_location_ids:
          Supported location\_ids used for deciding in which locations
          Pub/Sub topics need to be created. If custom Pub/Sub topics
          are used and they contains '{location}', the location\_ids
          will be used for validating the topics by replacing the
          '{location}' with the individual location in the list. The
          valid values are the "location\_id" field of the response of
          ``GET https://bigquerydatatransfer.googleapis.com/v1/{name=pro
          jects/*}/locations`` In addition, if the data source needs to
          support all available regions, supported\_location\_ids can be
          set to "global" (a single string element). When "global" is
          specified: 1) the data source implementation is supposed to
          stage the data in proper region of the destination dataset; 2)
          Data source developer should be aware of the implications
          (e.g., network traffic latency, potential charge associated
          with cross-region traffic, etc.) of supporting the "global"
          region;
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.DataSourceDefinition)
    ),
)
_sym_db.RegisterMessage(DataSourceDefinition)


DESCRIPTOR._options = None

_DATASOURCESERVICE = _descriptor.ServiceDescriptor(
    name="DataSourceService",
    full_name="google.cloud.bigquery.datatransfer.v1.DataSourceService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b("\312A#bigquerydatatransfer.googleapis.com"),
    serialized_start=3860,
    serialized_end=5937,
    methods=[
        _descriptor.MethodDescriptor(
            name="UpdateTransferRun",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceService.UpdateTransferRun",
            index=0,
            containing_service=None,
            input_type=_UPDATETRANSFERRUNREQUEST,
            output_type=google_dot_cloud_dot_bigquery_dot_datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERRUN,
            serialized_options=_b(
                "\202\323\344\223\002W2G/v1/{transfer_run.name=projects/*/locations/*/transferConfigs/*/runs/*}:\014transfer_run"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="LogTransferRunMessages",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceService.LogTransferRunMessages",
            index=1,
            containing_service=None,
            input_type=_LOGTRANSFERRUNMESSAGESREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                '\202\323\344\223\002K"F/v1/{name=projects/*/locations/*/transferConfigs/*/runs/*}:logMessages:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="StartBigQueryJobs",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceService.StartBigQueryJobs",
            index=2,
            containing_service=None,
            input_type=_STARTBIGQUERYJOBSREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                '\202\323\344\223\002Q"L/v1/{name=projects/*/locations/*/transferConfigs/*/runs/*}:startBigQueryJobs:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="FinishRun",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceService.FinishRun",
            index=3,
            containing_service=None,
            input_type=_FINISHRUNREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                '\202\323\344\223\002I"D/v1/{name=projects/*/locations/*/transferConfigs/*/runs/*}:finishRun:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="CreateDataSourceDefinition",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceService.CreateDataSourceDefinition",
            index=4,
            containing_service=None,
            input_type=_CREATEDATASOURCEDEFINITIONREQUEST,
            output_type=_DATASOURCEDEFINITION,
            serialized_options=_b(
                '\202\323\344\223\002S"9/v1/{parent=projects/*/locations/*}/dataSourceDefinitions:\026data_source_definition'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateDataSourceDefinition",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceService.UpdateDataSourceDefinition",
            index=5,
            containing_service=None,
            input_type=_UPDATEDATASOURCEDEFINITIONREQUEST,
            output_type=_DATASOURCEDEFINITION,
            serialized_options=_b(
                "\202\323\344\223\002j2P/v1/{data_source_definition.name=projects/*/locations/*/dataSourceDefinitions/*}:\026data_source_definition"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteDataSourceDefinition",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceService.DeleteDataSourceDefinition",
            index=6,
            containing_service=None,
            input_type=_DELETEDATASOURCEDEFINITIONREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                "\202\323\344\223\002;*9/v1/{name=projects/*/locations/*/dataSourceDefinitions/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetDataSourceDefinition",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceService.GetDataSourceDefinition",
            index=7,
            containing_service=None,
            input_type=_GETDATASOURCEDEFINITIONREQUEST,
            output_type=_DATASOURCEDEFINITION,
            serialized_options=_b(
                "\202\323\344\223\002;\0229/v1/{name=projects/*/locations/*/dataSourceDefinitions/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListDataSourceDefinitions",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceService.ListDataSourceDefinitions",
            index=8,
            containing_service=None,
            input_type=_LISTDATASOURCEDEFINITIONSREQUEST,
            output_type=_LISTDATASOURCEDEFINITIONSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002;\0229/v1/{parent=projects/*/locations/*}/dataSourceDefinitions"
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_DATASOURCESERVICE)

DESCRIPTOR.services_by_name["DataSourceService"] = _DATASOURCESERVICE

# @@protoc_insertion_point(module_scope)
